@@ -1,6 +1,6 @@
 package XML::NewsML_G2::News_Item;
 
-# $Id: News_Item.pm 46693 2013-06-11 08:28:45Z apatecgortan $
+# $Id: News_Item.pm 47068 2013-07-03 12:17:55Z apatecgortan $
 
 use XML::LibXML qw();
 use UUID::Tiny ':std';
@@ -98,16 +98,20 @@ __END__
 
 XML::NewsML_G2::News_Item - a news item (story)
 
+=for test_synopsis
+    my ($provider, $service, $genre1, $genre2);
+
 =head1 SYNOPSIS
 
     my $ni = XML::NewsML_G2::News_Item->new
-        (guid => $guid,
+        (guid => "tag:example.com,2013:service:date:number",
          title => "Story title",
          slugline => "the/slugline",
          language => 'de',
-         provider => $provider_instance,
-         service => $service_instance,
+         provider => $provider,
+         service => $service,
         );
+
     $ni->add_genre($genre1, $genre2);
     $ni->add_source('APA');
     $ni->add_paragraph('blah blah blah');
